@@ -17,6 +17,16 @@ cross <- function(v1, v2) {
 	return(c(cx, -cy, cz))
 }
 
+interiorTriangle <- function(triangle2D, point) {
+	vectors2D <- rbind(triangle2D[2, ] - triangle2D[1, ], triangle2D[3, ] - triangle2D[1, ])
+	det.v <- vectors2D[1, 1] * vectors2D[2, 2] - vectors2D[1, 2] * vectors2D[2, 1]
+	Ct <- matrix(c(vectors2D[2, 2], 
+					-vectors2D[1, 2], -vectors2D[2, 1], vectors2D[1, 1]), ncol = 2)
+	xs <- (1 / det.v) * Ct %*% (point - triangle2D[1, ])
+	inside <- (xs[1] >0 & xs[2] > 0 & sum(xs) < 1)
+	return(inside)
+}
+
 triangleIntersection <- function(triangle3D, segment) {
 	v1 <- triangle3D[3, ] - triangle3D[1, ]
 	v2 <- triangle3D[2, ] - triangle3D[1, ]
@@ -27,15 +37,7 @@ triangleIntersection <- function(triangle3D, segment) {
 	return(inside)
 } 
 
-interiorTriangle <- function(triangle2D, point) {
-	vectors2D <- rbind(triangle2D[2, ] - triangle2D[1, ], triangle2D[3, ] - triangle2D[1, ])
-	det.v <- vectors2D[1, 1] * vectors2D[2, 2] - vectors2D[1, 2] * vectors2D[2, 1]
-	Ct <- matrix(c(vectors2D[2, 2], 
-			-vectors2D[1, 2], -vectors2D[2, 1], vectors2D[1, 1]), ncol = 2)
-	xs <- (1 / det.v) * Ct %*% (point - triangle2D[1, ])
-	inside <- (xs[1] >0 & xs[2] > 0 & sum(xs) < 1)
-	return(inside)
-}
+
 
 
 segmentSet <- function(comp, i, extends)
@@ -46,6 +48,52 @@ segmentSet <- function(comp, i, extends)
 	return(set)
 }
 	
+#move3DOLD <- function(points3D, ends) {
+#	ncomp <- length(ends) + 1
+#	repeat { 
+#		extends <- c(0, ends, nrow(points3D))
+#		npoints <- nrow(points3D)
+#		npoints.in <- npoints
+#		component <- 1 
+#		while (component <= ncomp){
+#			perm <- c(3, 1, 2, 3)
+#			points3D.comp <- points3D[(extends[component] + 1) : extends[component + 1], ]
+#			npoints.comp <- nrow(points3D.comp)
+#			while (max(perm) <= npoints.comp) 
+#			{
+#				triangle <- points3D.comp[perm, ]
+#				intersections <- c()
+#				segments <- segmentSet(component, perm[2], extends)
+#				for (i in segments) { 
+#					segment <- rbind(points3D[i, ], points3D[i + 1, ])
+#					intersections <- unique(c(intersections, triangleIntersection(triangle, 
+#											segment)) )
+#				}
+#				if (length(intersect(unique(intersections), TRUE)) != 0) {
+#					perm <- perm + 1
+#					next
+#				}
+#				total <- unique( intersections )
+#				if (identical(total, FALSE) | identical(total, c())) 
+#					points3D <- points3D[-(extends[component]+perm[3]), ]
+#				perm <- perm + 1
+#				npoints <- nrow(points3D)
+#				npoints.comp <- npoints.comp - 1
+#				extends[(component + 1) : length(extends)] <- extends[(component + 1) : length(extends)] - 1
+#				ends <- extends[-c(1, length(extends))]
+#				points3D.comp <- points3D[(extends[component] + 1) : extends[component + 1],]
+#				npoints.comp <- nrow(points3D.comp)
+#			}
+#			component <- component+1
+#		}
+#		if (npoints == npoints.in) 
+#			break
+#	}
+#	return(list(points3D = points3D, ends = extends[-c(1, length(extends))]))
+#}
+
+
+
 move3D <- function(points3D, ends) {
 	ncomp <- length(ends) + 1
 	repeat { 
@@ -64,15 +112,15 @@ move3D <- function(points3D, ends) {
 				segments <- segmentSet(component, perm[2], extends)
 				for (i in segments) { 
 					segment <- rbind(points3D[i, ], points3D[i + 1, ])
-					intersections <- unique(c(intersections, triangleIntersection(triangle, 
-											segment)) )
+					intersections <- c(intersections, triangleIntersection(triangle, segment)) 
 				}
-				if (length(intersect(unique(intersections), TRUE)) != 0) {
+				if (length(intersect(intersections, TRUE)) != 0) {
 					perm <- perm + 1
 					next
 				}
-				total <- unique( intersections )
-				if (identical(total, FALSE) | identical(total, c())) 
+				#total <- unique( intersections )
+				#if (identical(total, FALSE) | identical(total, c())) 
+				if( !all(intersections) || is.null(intersections) )
 					points3D <- points3D[-(extends[component]+perm[3]), ]
 				perm <- perm + 1
 				npoints <- nrow(points3D)
@@ -82,7 +130,7 @@ move3D <- function(points3D, ends) {
 				points3D.comp <- points3D[(extends[component] + 1) : extends[component + 1],]
 				npoints.comp <- nrow(points3D.comp)
 			}
-			component <- component+1
+			component <- component + 1
 		}
 		if (npoints == npoints.in) 
 			break
@@ -90,6 +138,8 @@ move3D <- function(points3D, ends) {
 	return(list(points3D = points3D, ends = extends[-c(1, length(extends))]))
 }
 
+
+
 AlexanderBriggs <- function(points3D, ends = c()) {
 	points3D <- move3D(points3D, ends)
 	return(points3D)
