@@ -5,10 +5,9 @@
 # Author: Federico Comoglio @ D-BSSE, ETH Zurich
 ###############################################################################
 
-centroidClosure <- function (points3D, n.times = 2) {
-	
+centroidClosure <- function (points3D, w = 2) {
+	w <- w + .05
 	normV <- function (v)	return(sqrt(sum(v ^ 2)))
-	
 	findRadius <- function(points3D, G) {
 		D <- apply(points3D, 1, function(x) normV(x - G))
 		return(max(D))
@@ -16,11 +15,15 @@ centroidClosure <- function (points3D, n.times = 2) {
 	
 	n <- nrow(points3D)
 	G <- colMeans(points3D)
-	radius <- n.times * findRadius(points3D, G)
+	radius <- findRadius(points3D, G)
 	
-	first.point <- G + radius * ((points3D[1, ] - G) / 
+	#cannot extend less than the trivial (null) extension
+	if( w < max( normV(points3D[1,	] - G), normV(points3D[n, ] - G) ) / radius)
+		return('the supplied parameter w is not correct. Any k > 1 will do.')
+	
+	first.point <- G + w * radius * ((points3D[1, ] - G) / 
 				(normV(points3D[1,	] - G)))
-	last.point <- G + radius * ((points3D[n, ] - G) / 
+	last.point <- G + w * radius * ((points3D[n, ] - G) / 
 				(normV(points3D[n, ] - G)))
 	points3D <- rbind(as.numeric(first.point), 
 			points3D, as.numeric(last.point))
